import { IRelativePattern } from '@vscode-alt/monaco-editor/esm/vs/base/common/glob';
import { Event } from '@vscode-alt/monaco-editor/esm/vs/base/common/event';
import { URI, UriComponents } from '@vscode-alt/monaco-editor/esm/vs/base/common/uri';
import { IRange } from '@vscode-alt/monaco-editor/esm/vs/editor/common/core/range';
import { IMarkdownString } from '@vscode-alt/monaco-editor/esm/vs/base/common/htmlContent';
import * as langModes from '@vscode-alt/monaco-editor/esm/vs/editor/common/modes';
import { IModelContentChange } from '@vscode-alt/monaco-editor/esm/vs/editor/common/model/textModelEvents';
type Command = langModes.Command;
export interface ITextEditorSelection {
    readonly startLineNumber: number;
    readonly startColumn: number;
    readonly endLineNumber?: number;
    readonly endColumn?: number;
}
export interface LanguageFilter {
    language?: string;
    scheme?: string;
    pattern?: string | IRelativePattern;
    /**
     * This provider is implemented in the UI thread.
     */
    hasAccessToAllModels?: boolean;
    exclusive?: boolean;
}
export type LanguageSelector = string | LanguageFilter | Array<string | LanguageFilter>;
export interface IModelChangedEvent {
    /**
     * The actual changes.
     */
    readonly changes: IModelContentChange[];
    /**
     * The (new) end-of-line character.
     */
    readonly eol: string;
    /**
     * The new version id the model has transitioned to.
     */
    readonly versionId: number;
}
export interface ITerminalDimensions {
    /**
     * The columns of the terminal.
     */
    readonly cols: number;
    /**
     * The rows of the terminal.
     */
    readonly rows: number;
}
export declare namespace modes {
    /**
       * @internal
       */
    interface CommentInfo {
        extensionId: string;
        threads: CommentThread[];
        commentingRanges?: (IRange[] | CommentingRanges);
        reply?: Command;
        draftMode: DraftMode;
    }
    /**
     * @internal
     */
    enum DraftMode {
        NotSupported = 0,
        InDraft = 1,
        NotInDraft = 2
    }
    /**
     * @internal
     */
    enum CommentThreadCollapsibleState {
        /**
         * Determines an item is collapsed
         */
        Collapsed = 0,
        /**
         * Determines an item is expanded
         */
        Expanded = 1
    }
    /**
     * @internal
     */
    interface CommentWidget {
        commentThread: CommentThread;
        comment?: Comment;
        input: string;
        onDidChangeInput: Event<string>;
    }
    /**
     * @internal
     */
    interface CommentInput {
        value: string;
        uri: URI;
    }
    /**
     * @internal
     */
    interface CommentThread2 {
        commentThreadHandle: number;
        extensionId: string;
        threadId: string;
        resource: string;
        range: IRange;
        label: string;
        comments: Comment[];
        onDidChangeComments: Event<Comment[]>;
        collapsibleState?: CommentThreadCollapsibleState;
        input: CommentInput;
        onDidChangeInput: Event<CommentInput>;
        acceptInputCommand?: Command;
        additionalCommands: Command[];
        onDidChangeAcceptInputCommand: Event<Command>;
        onDidChangeAdditionalCommands: Event<Command[]>;
        onDidChangeRange: Event<IRange>;
        onDidChangeLabel: Event<string>;
        onDidChangeCollasibleState: Event<CommentThreadCollapsibleState>;
    }
    /**
     * @internal
     */
    interface CommentingRanges {
        readonly resource: URI;
        ranges: IRange[];
        newCommentThreadCommand?: Command;
        newCommentThreadCallback?: (uri: UriComponents, range: IRange) => void;
    }
    /**
     * @internal
     */
    interface CommentThread {
        extensionId: string;
        threadId: string;
        resource: string;
        range: IRange;
        comments: Comment[];
        collapsibleState?: CommentThreadCollapsibleState;
        reply?: Command;
    }
    /**
     * @internal
     */
    interface NewCommentAction {
        ranges: IRange[];
        actions: Command[];
    }
    /**
     * @internal
     */
    interface CommentReaction {
        readonly label?: string;
        readonly iconPath?: UriComponents;
        readonly count?: number;
        readonly hasReacted?: boolean;
        readonly canEdit?: boolean;
    }
    /**
     * @internal
     */
    interface Comment {
        readonly commentId: string;
        readonly body: IMarkdownString;
        readonly userName: string;
        readonly userIconPath: string;
        readonly canEdit?: boolean;
        readonly canDelete?: boolean;
        readonly command?: Command;
        readonly editCommand?: Command;
        readonly deleteCommand?: Command;
        readonly isDraft?: boolean;
        readonly commentReactions?: CommentReaction[];
        readonly label?: string;
    }
    /**
     * @internal
     */
    interface CommentThreadChangedEvent {
        /**
         * Added comment threads.
         */
        readonly added: (CommentThread | CommentThread2)[];
        /**
         * Removed comment threads.
         */
        readonly removed: (CommentThread | CommentThread2)[];
        /**
         * Changed comment threads.
         */
        readonly changed: (CommentThread | CommentThread2)[];
        /**
         * changed draft mode.
         */
        readonly draftMode?: DraftMode;
    }
}
export {};
